@@ -71,7 +71,7 @@
 //!
 //! The archive.org version is the most up-to-date one.
 
-#![doc(html_root_url = "https://docs.rs/jaylink/0.2.0")]
+#![doc(html_root_url = "https://docs.rs/jaylink/0.3.0")]
 // Deny a few warnings in doctests, since rustdoc `allow`s many warnings by default
 #![doc(test(attr(deny(unused_imports, unused_must_use))))]
 #![warn(missing_debug_implementations, rust_2018_idioms, unreachable_pub)]
@@ -1414,10 +1414,11 @@ impl SpeedInfo {
 pub struct SwoSpeedInfo {
     base_freq: u32,
     min_div: u32,
+    #[allow(dead_code)]
     max_div: u32,
 
-    // FIXME: Not sure what these are for.
     min_presc: u32,
+    #[allow(dead_code)]
     max_presc: u32,
 }
 
